@@ -37,16 +37,17 @@ class WebApi(threading.Thread):
 #qForGui format: [device_index, retCode, QRcode, message]
         
     def addTest(self):
+        profile = main_paras.info.getProfile(main_paras.sign_in_user)
         
         service = "/ctestlookspot/addtest"
         url  = baseUrl+service
         payload = json.dumps({
           "passtoken": self.passToken,
           "testid": self.cassetteId,
-          "site": main_paras.test_provider,
-          "place": self.address[0],
-          "city": self.address[1],
-          "country": self.address[2],
+          "site": profile['provider'],
+          "place": profile['place'],
+          "city": profile['city'],
+          "country": profile['country'],
           "timestamp": str(self.timeStamp)+'000',
           "mode": main_paras.test_mode,
           "localdate": time.strftime("%d/%m/%Y",time.localtime(self.timeStamp)),
