@@ -1,20 +1,28 @@
 import time
 import json
+from operator import itemgetter
 import sys, os, inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 
 import main_paras
+from define import *
 
 if sys.platform == 'linux':
     PROFILE_FOLDER = '/home/pi/app/spotii'
 else:
     PROFILE_FOLDER = currentdir
 
-
-#defaultLanguage = 'English'
-
 DEFAULT_LANGUAGE = 'English'
 
+##profile = {
+##    'user': 'feng.gao@laipac.com',
+##    'place': 'office',
+##    'city': 'Markham',
+##    'country': 'Canada',
+##    'provider':	'Laipac'    
+##    }
+
+
 
 basic = {
     'language': DEFAULT_LANGUAGE,
@@ -41,6 +49,9 @@ class Config():
                 self.profile_list = json.load(infile)
                 if self.profile_list['basic']['language'] not in self.languageList:
                     self.profile_list['basic']['language'] = DEFAULT_LANGUAGE
+##                if self.profile_list['person'] !=[]:
+##                    if self.profile_list['person']['user'] == '':
+##                        self.profile_list['person'].clear()
         except Exception as e:
             print(e)
 
@@ -93,13 +104,34 @@ class Config():
                         profile[key] = person[key]
                 break;
         return profile
+
+    def lastUser(self):
+        if len(self.profile_list['person']) == 0:
+            return ''
+        return self.profile_list['person'][-1]['user']
+
+    def saveUser(self,user):
+        for i, person in enumerate(self.profile_list['person']):
+            if user == person['user']:
+                return;
+        profile = main_paras.empty.copy()
+        profile['user']=user
+        self.profile_list['person'].append(profile)
+        self.save()
+    
+    
     def setProfile(self, profile):
+        delete_out = len(self.profile_list['person']) - MAX_PROFILES
+        if delete_out>0:
+            del self.profile_list['person'][0:delete_out]
         for i, person in enumerate(self.profile_list['person']):
             if profile['user'] == person['user']:
-                self.profile_list['person'][i] = profile
+                del self.profile_list['person'][i]
                 break;
         else:
-            self.profile_list['person'].append(profile)        
+            del self.profile_list['person'][0]
+            
+        self.profile_list['person'].append(profile)
         self.save()
 
     def clear(self):
