@@ -155,12 +155,12 @@ TKEN = 'passtoken'
 RCID = 'testRecordId'
 RCODE= 'retCode'
 MSSG = 'message'
-ADDRESS =["finch","Toronto","Canada"]
+#ADDRESS =["finch","Toronto","Canada"]
 
 
 #@SIGNATURE = "client=laipac&signature=laipacws"
 #USER      = "userid=feng.gao@laipac.com&password=123456"
-SERIAL_NO = "654321"
+#SERIAL_NO = "654321"
 CASSETTE_DETECTION_MODE_AUTO   = 'auto mode'
 CASSETTE_DETECTION_MODE_MANUAL = 'manual mode'
 
@@ -183,6 +183,7 @@ TEST_MODE_SPEED = 0
 TEST_MODE_NORMAL = 1
 
 popUp = None
+MAX_PROFILES = 2
 #trans = None
 
-LANGUAGE_LIST = ['English', 'Spanish', 'French', 'Japanese', 'Indonesian', 'Arabic', 'Thailand', 'Chinese Traditional']
+#LANGUAGE_LIST = ['English', 'Spanish', 'French', 'Japanese', 'Indonesian', 'Arabic', 'Thailand', 'Chinese Traditional']
