@@ -40,12 +40,13 @@ class _ProfileDetail(QtWidgets.QDialog):
             self.change_psw.clicked.connect(self.change_psw_hook)
             self.language.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
             self.language.clicked.connect(self.language_hook)
-
+            
+            profile = main_paras.info.getProfile(main_paras.sign_in_user)
             self.user_id_show.setText(main_paras.sign_in_user)
-            self.place_show.setText(main_paras.test_place)
-            self.city_show.setText(main_paras.test_city)
-            self.country_show.setText(main_paras.test_country)
-            self.provider_show.setText(main_paras.test_provider)
+            self.place_show.setText(profile['place'])
+            self.city_show.setText(profile['city'])
+            self.country_show.setText(profile['country'])
+            self.provider_show.setText(profile['provider'])
             if main_paras.getTestMode() == TEST_MODE_SPEED:
                 self.testing_mode_show.setText(self.tr('SPEED'))
             else:
