@@ -7,6 +7,7 @@ import queue
 
 import sys, os, inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+sys.path.insert(0, currentdir)
 parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
 
@@ -14,6 +15,7 @@ from test_handler.i2c_lib import i2c_device
 from test_handler.cassette_polling import CassettePolling
 from define import *
 from main_paras import getTestMode
+from on_off.mainboard_pio import hub_reset
 # from smbus import SMBus
 # import sys
 # sys.path.append('/home/pi/gxf/python/spotii')
@@ -48,6 +50,7 @@ def usbCameraFinder(deviceInfo):
 def cameraMap(cMap):
     try:
         usbList=subprocess.check_output(['v4l2-ctl','--list-devices']).decode("utf-8").split('(usb-0000:')
+        
     except Exception as e:
         print("cameraMap exception:",e)
         return False
@@ -55,7 +58,7 @@ def cameraMap(cMap):
     for phase in usbList[1:]:
 #        print (phase)
         cameraList=usbCameraFinder(phase)
-#        print(cameraList)
+        print(cameraList)
         if(cameraList):
             cMap[cameraList[0]][1]=cameraList[1]
     return True
@@ -88,14 +91,7 @@ class TestChipHandlerThread (threading.Thread):
         self.i2c=[]
         self.cmrMap=[]
         self.initDone = True
-        for addr in I2C_DEVICE:
-            self.cmrMap.append([addr, INVALID_DEVICE_INDEX])
-        if cameraMap(self.cmrMap)==False:
-            self.initDone =False
-            return 
-        print(self.cmrMap)
-        i2cMap(self.cmrMap)
-        print(self.cmrMap)
+
         self.deviceQue=[]
         self.checkingResult=[]  # [[0,0,0,0,0,0,0], ..., [0,0,0,0,0,0,0]] total (I2C_PORT)
                     #
@@ -164,6 +160,23 @@ class TestChipHandlerThread (threading.Thread):
         super().run()
         print('test monitor run...')
         
+        for addr in I2C_DEVICE:
+            self.cmrMap.append([addr, INVALID_DEVICE_INDEX])            
+        for i in range(3):
+            if cameraMap(self.cmrMap)==True:
+                break;
+            self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
+            hub_reset.off()
+            time.sleep(0.5)
+            hub_reset.on()
+            time.sleep(4)           
+        else:
+            self.initDone =False
+             
+        print(self.cmrMap)
+        i2cMap(self.cmrMap)
+        print(self.cmrMap)
+        
         if self.initDone == False:
             self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
             while True:
@@ -229,6 +242,10 @@ def i2cTest():
 # 
     
 def cameraMapTest():
+    hub_reset.off()
+    time.sleep(0.1)
+    hub_reset.on()
+    time.sleep(2)
     cmrMap=[]
     for addr in I2C_DEVICE:
         cmrMap.append([addr, INVALID_DEVICE_INDEX])
@@ -260,8 +277,8 @@ def threadTest():
     TestMonitor.start()
 if __name__ == "__main__":
 
-    threadTest()
-#    cameraMapTest()   
+#    threadTest()
+    cameraMapTest()   
 #    i2cTest()
 #    hubTest();        
         
